import { EventEmitter, Renderer2, OnDestroy, ElementRef, OnInit, ChangeDetectorRef } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { OverlayComponent } from '../overlay';
import { OverlayOriginDirective } from '../overlay/overlay-origin.directive';
/**
 * DatePicker Component
 */
export declare class DatePickerComponent implements OnInit, OnDestroy, ControlValueAccessor {
    private render;
    private cd;
    private el;
    /** datepicker change event */
    change: EventEmitter<any>;
    /**
     * selected date
     */
    value: Date;
    /** whether the datepicker is disabled */
    disabled: boolean;
    /**
     * the strategy function which used to check weather the date is disabled
     */
    disabledStrategy: (date: Date) => boolean;
    /**
     * show text in input box
     * @readonly
     * @docs-private
     */
    readonly valueText: string;
    /** whether the panel is show */
    _showPanel: boolean;
    origin: OverlayOriginDirective;
    overlay: OverlayComponent;
    constructor(render: Renderer2, cd: ChangeDetectorRef, el: ElementRef);
    ngOnInit(): void;
    ngOnDestroy(): void;
    onShowCalendar(): void;
    _hideOverlay(): void;
    _showOverlay(): void;
    onSelectDate(date: Date): void;
    onFilterPanelHide(_panel: any): void;
    /**
     * The method to be called in order to update ngModel.
     * Now `ngModel` binding is not supported in multiple selection mode.
     */
    private _onModelChange;
    /**
     * Registers a callback that will be triggered when the value has changed.
     * Implemented as part of ControlValueAccessor.
     * @param fn On change callback function.
     */
    registerOnChange(fn: Function): void;
    /** onTouch function registered via registerOnTouch (ControlValueAccessor). */
    private _onTouch;
    /**
     * Registers a callback that will be triggered when the control has been touched.
     * Implemented as part of ControlValueAccessor.
     * @param fn On touch callback function.
     */
    registerOnTouched(fn: Function): void;
    /**
     * Sets the model value. Implemented as part of ControlValueAccessor.
     * @param {any} value - value to be set to the model.
     */
    writeValue(value: any): void;
    /**
     * Toggles the disabled state of the component. Implemented as part of ControlValueAccessor.
     * @param {boolean} isDisabled - Whether the component should be disabled.
     */
    setDisabledState(isDisabled: boolean): void;
    /**
     * update form model value and mark for check
     * @docs-private
     */
    _markForCheck(): void;
}
