import { EventEmitter, ElementRef, Renderer2, AfterViewInit, OnDestroy } from '@angular/core';
import { EChartOption, ECharts } from 'echarts';
/**
 * Chart Component, depends on [Echarts](http://echarts.baidu.com/)
 */
export declare class ChartComponent implements AfterViewInit, OnDestroy {
    private _el;
    private _renderer;
    /**
     * chart init event
     */
    chartInit: EventEmitter<ECharts>;
    /**
     * chart event
     */
    chartEvent: EventEmitter<any>;
    /**
     * chart event name
     * @default click
     */
    eventName: string;
    /**
     * chart width, can be a number(400) or a percent(30%)
     * @default 600
     */
    width: number | string;
    widthChange: EventEmitter<number | string>;
    /**
     * chart height, can be a number(400) or a percent(30%)
     * @default 400
     */
    height: number | string;
    heightChange: EventEmitter<number | string>;
    /**
     * chart title
     * @default ''
     */
    chartTitle: string;
    /**
     * chart options, see [echarts options](http://echarts.baidu.com/option.html)
     */
    options: EChartOption;
    /**
     * callback when chart options change
     * @docs-private
     */
    optionsChange: EventEmitter<any>;
    _chartContainer: ElementRef;
    /**
     * chart instance
     * @docs-private
     */
    _chartInstance: any;
    /** chart auto resize when window resize */
    _resizeListener: any;
    /** if chart event is binded */
    _eventBinded: boolean;
    constructor(_el: ElementRef, _renderer: Renderer2);
    /**
     * set window resize handler
     * @docs-private
     */
    setOptionsChangeListener(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
}
